# Prosopopee

More or less a small clone of exposure.co in form of a static generator. For
those of you who don't know what exposure.co is, this allows you to tell a
story with your pictures.

Prosopopee. Static site generator for your story.

```
Usage:

prosopopee
prosopopee preview
prosopopee deploy
prosopopee (-h | --help)
prosopopee.py --version
```

## Licence 

GLPv3

## Documentation

  http://prosopopee.readthedocs.org/en/latest/

## Exemple

You can find example usages here:

* http://surleschemins.fr
* http://media.faimaison.net/photos/galerie/
* https://www.thebrownianmovement.org/
* http://outside.browny.pink
* http://such.life


